@@ -103,18 +103,19 @@ def condexp_cat(
     x: pd.DataFrame,
     y: pd.Series,
     var: str,
-    n_max: int = 25,
+    n_categories: int = 25,
 ) -> alt.Chart:
     """Conditional expectations plot for categorical variables"""
     pred = func(x)
-    df = x.assign(pred=pred, y=y).astype({var: "category"})
 
     df_agg = (
-        df.groupby(var, as_index=False, observed=True)
+        x.assign(pred=pred, y=y)
+        .astype({var: "category"})
+        .groupby(var, as_index=False, observed=True)
         .agg({"y": "mean", "pred": ["mean", "count"]})
         .pipe(flatten_index)
         .sort_values(("pred", "count"), ascending=False)
-        .head(n_max)  # keep most frequent
+        .head(n_categories)  # keep most frequent
         .sort_values(("pred", "mean"), ascending=False)
         .rename(
             columns={
